@@ -41,10 +41,8 @@ import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
 import java.util.ArrayList;
 import java.util.Enumeration;
-import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
-import java.util.Set;
 
 import javax.imageio.ImageIO;
 import javax.swing.BorderFactory;
@@ -189,6 +187,9 @@ public class MainGUI extends JFrame implements MapEventListener {
 	private JCheckBox wgsGridCheckBox;
 	private JComboBox<WgsDensity> wgsGridCombo;
 
+	public JCheckBox rulerCheckBox;
+	public JButton rulerButtonClear;
+
 	private JLabel zoomLevelText;
 	private JComboBox<GridZoom> gridZoomCombo;
 	private JSlider zoomSlider;
@@ -214,6 +215,9 @@ public class MainGUI extends JFrame implements MapEventListener {
 	private JPanel leftPanelContent = null;
 	private JPanel rightPanel = new JPanel(new GridBagLayout());
 
+	private JCollapsiblePanel zoomLevelsPanel;
+	private JCollapsiblePanel atlasContentPanel;
+
 	public JMenu logLevelMenu;
 	private JMenuItem smRectangle;
 	private JMenuItem smPolygon;
@@ -384,6 +388,38 @@ public class MainGUI extends JFrame implements MapEventListener {
 			}
 		});
 
+		// ruler. measuring tool
+		rulerCheckBox = new JCheckBox();
+		rulerCheckBox.setVisible(true);
+		rulerCheckBox.setText(I18nUtils.localizedStringForKey("map_ctrl_ruler_title"));
+		rulerCheckBox.setToolTipText(I18nUtils.localizedStringForKey("map_ctrl_ruler_tooltip"));
+		rulerCheckBox.setOpaque(true);
+		rulerCheckBox.setBackground(checkboxBackgroundColor);
+		rulerCheckBox.setForeground(labelForegroundColor);
+		rulerCheckBox.setMargin(new Insets(0, 0, 0, 0));
+		rulerCheckBox.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				if (rulerCheckBox.isSelected()) {
+					previewMap.runRuler("start");
+					rulerButtonClear.setVisible(previewMap.isMeasuring);
+				} else {
+					previewMap.runRuler("exit");
+					rulerButtonClear.setVisible(false);
+				}
+			}
+		});
+
+		rulerButtonClear = new JButton();
+		rulerButtonClear.setVisible(false);
+		rulerButtonClear.setText(I18nUtils.localizedStringForKey("map_ctrl_ruler_clear"));
+		rulerButtonClear.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				previewMap.runRuler("clear");
+			}
+		});
+
 		// map source tree
 		mapSourceTree = new JMapSourceTree(MapSourcesManager.getInstance().getEnabledOrderedMapSources());
 		mapSourceTree.addTreeSelectionListener(new MapSourceTreeListener());
@@ -675,8 +711,7 @@ public class MainGUI extends JFrame implements MapEventListener {
 
 		mapSourcePanel = new JMapSourcesPanel(mapSourceTree);
 
-		JCollapsiblePanel zoomLevelsPanel = new JCollapsiblePanel(I18nUtils.localizedStringForKey("lp_zoom_title"),
-				new GridBagLayout());
+		zoomLevelsPanel = new JCollapsiblePanel(I18nUtils.localizedStringForKey("lp_zoom_title"), new GridBagLayout());
 		zoomLevelsPanel.addContent(zoomLevelPanel, GBC.eol().insets(2, 4, 2, 0));
 		zoomLevelsPanel.addContent(amountOfTilesLabel, GBC.std().anchor(GBC.WEST).insets(0, 5, 0, 2));
 
@@ -685,7 +720,7 @@ public class MainGUI extends JFrame implements MapEventListener {
 		GBC gbc_std = GBC.std().insets(5, 2, 5, 3);
 		GBC gbc_eol = GBC.eol().insets(LEFT_PANEL_MARGIN, 2, LEFT_PANEL_MARGIN, 3);
 
-		JCollapsiblePanel atlasContentPanel = new JCollapsiblePanel(I18nUtils.localizedStringForKey("lp_atlas_title"),
+		atlasContentPanel = new JCollapsiblePanel(I18nUtils.localizedStringForKey("lp_atlas_title"),
 				new GridBagLayout());
 		JScrollPane treeScrollPane = new JScrollPane(jAtlasTree, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
 				JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
@@ -747,6 +782,8 @@ public class MainGUI extends JFrame implements MapEventListener {
 		topControls.add(gridZoomCombo, GBC.std().insets(10, 5, 0, 0));
 		topControls.add(wgsGridCheckBox, GBC.std().insets(10, 5, 0, 0));
 		topControls.add(wgsGridCombo, GBC.std().insets(5, 5, 0, 0));
+		topControls.add(rulerCheckBox, GBC.std().insets(10, 5, 0, 0));
+		topControls.add(rulerButtonClear, GBC.std().insets(10, 5, 0, 0));
 		topControls.add(Box.createHorizontalGlue(), GBC.std().fillH());
 		mapControlPanel.add(topControls, BorderLayout.NORTH);
 
@@ -769,16 +806,18 @@ public class MainGUI extends JFrame implements MapEventListener {
 		}
 		MapSource ms2 = mapSourceTree.getSelectedMapSource();
 
-		if (!ms.equals(ms2))
+		if (!ms.equals(ms2)) {
 			previewMap.setMapSource(ms2);
+		}
 	}
 
 	public void updateBookmarksMenu() {
 		LinkedList<JMenuItem> items = new LinkedList<JMenuItem>();
 		for (int i = 0; i < bookmarkMenu.getMenuComponentCount(); i++) {
 			JMenuItem item = bookmarkMenu.getItem(i);
-			if (!(item instanceof JBookmarkMenuItem))
+			if (!(item instanceof JBookmarkMenuItem)) {
 				items.add(item);
+			}
 		}
 		bookmarkMenu.removeAll();
 		for (JMenuItem item : items) {
@@ -796,6 +835,11 @@ public class MainGUI extends JFrame implements MapEventListener {
 		}
 	}
 
+	public void setEnableLeftPanel(boolean enabled) {
+		zoomLevelsPanel.setVisible(enabled);
+		atlasContentPanel.setVisible(enabled);
+	}
+
 	private void loadSettings() {
 		if (Profile.DEFAULT.exists()) {
 			try {
@@ -826,13 +870,6 @@ public class MainGUI extends JFrame implements MapEventListener {
 			}
 		}
 
-		Set<String> trustedCertificatesLowerCase = new HashSet<>();
-		for (String hash : settings.trustedCertificates) {
-			trustedCertificatesLowerCase.add(hash.toLowerCase());
-		}
-		settings.trustedCertificates.clear();
-		settings.trustedCertificates.addAll(trustedCertificatesLowerCase);
-
 		coordinatesPanel.setNumberFormat(settings.coordinateNumberFormat);
 
 		tileImageParametersPanel.loadSettings();
