@@ -95,7 +95,7 @@ import mobac.utilities.Utilities;
 public class SettingsGUI extends JDialog {
 	private static final long serialVersionUID = -5227934684609357198L;
 
-	public static Logger log = Logger.getLogger(SettingsGUI.class);
+	private static final Logger LOG = Logger.getLogger(SettingsGUI.class);
 
 	private static final Integer[] THREADCOUNT_LIST = { 1, 2, 4, 6 };
 
@@ -126,6 +126,7 @@ public class SettingsGUI extends JDialog {
 	private enum SupportLocale {
 		SupportLocaleEn(new Locale("en"), "English"), // default
 		SupportLocaleFrFR(new Locale("fr", "FR"), "Français"), // French
+		SupportLocaleRuRu(new Locale("ru", "RU"), "Russian"), // Russian
 		SupportLocaleJaJP(new Locale("ja", "JP"), "日本語"), // Japanese
 		SupportLocaleZhCN(new Locale("zh", "CN"), "简体中文"), // Chinese (simplified)
 		SupportLocaleZhTW(new Locale("zh", "TW"), "繁體中文"); // Chinese (Taiwan)
@@ -212,6 +213,7 @@ public class SettingsGUI extends JDialog {
 
 	private SettingsGUI(JFrame owner) {
 		super(owner);
+		LOG.debug("Preparing settings dialog");
 		setIconImages(MainGUI.MOBAC_ICONS);
 		GUIExceptionHandler.registerForCurrentThread();
 		setDefaultCloseOperation(DISPOSE_ON_CLOSE);
@@ -226,11 +228,14 @@ public class SettingsGUI extends JDialog {
 		createJButtons();
 		loadSettings();
 		addListeners();
+		LOG.trace("Settings dialog preparation finished");
+
 		pack();
 		// don't allow shrinking, but allow enlarging
 		setMinimumSize(getSize());
 		Dimension dScreen = Toolkit.getDefaultToolkit().getScreenSize();
 		setLocation((dScreen.width - getWidth()) / 2, (dScreen.height - getHeight()) / 2);
+		LOG.trace("Make settings dialog visible");
 		setVisible(true);
 	}
 
@@ -247,7 +252,7 @@ public class SettingsGUI extends JDialog {
 		try {
 			addMapSourceSettingsPanel();
 		} catch (URISyntaxException e) {
-			log.error("", e);
+			LOG.error("", e);
 		}
 		addMapSourceManagerPanel();
 		addTileUpdatePanel();
@@ -273,6 +278,7 @@ public class SettingsGUI extends JDialog {
 	}
 
 	private void addDisplaySettingsPanel() {
+		LOG.trace("addDisplaySettingsPanel");
 		JPanel tab = createNewTab(I18nUtils.localizedStringForKey("set_display_title"));
 		tab.setLayout(new GridBagLayout());
 
@@ -326,7 +332,7 @@ public class SettingsGUI extends JDialog {
 								}
 								command.add(currentJar.getPath());
 
-								log.debug("restarting MOBAC using the following command: \n\t"
+								LOG.debug("restarting MOBAC using the following command: \n\t"
 										+ Arrays.toString(command.toArray()));
 								final ProcessBuilder builder = new ProcessBuilder(command);
 								builder.start();
@@ -357,6 +363,7 @@ public class SettingsGUI extends JDialog {
 	}
 
 	private void addMapSourceSettingsPanel() throws URISyntaxException {
+		LOG.trace("addMapSourceSettingsPanel");
 
 		JPanel tab = createNewTab(I18nUtils.localizedStringForKey("set_mapsrc_config_title"));
 		tab.setLayout(new GridBagLayout());
@@ -387,6 +394,7 @@ public class SettingsGUI extends JDialog {
 	}
 
 	private void addMapSourceManagerPanel() {
+		LOG.trace("addMapSourceManagerPanel");
 		JPanel tab = createNewTab(I18nUtils.localizedStringForKey("set_mapsrc_mgr_title"));
 		tab.setLayout(new GridBagLayout());
 
@@ -464,6 +472,7 @@ public class SettingsGUI extends JDialog {
 	}
 
 	private void addTileUpdatePanel() {
+		LOG.trace("addTileUpdatePanel");
 		JPanel backGround = createNewTab(I18nUtils.localizedStringForKey("set_tile_update_title"));
 		backGround.setLayout(new GridBagLayout());
 
@@ -515,13 +524,14 @@ public class SettingsGUI extends JDialog {
 	}
 
 	private void addMapSizePanel() {
+		LOG.trace("addMapSizePanel");
 		JPanel backGround = createNewTab(I18nUtils.localizedStringForKey("set_map_size_title"));
 		backGround.setLayout(new GridBagLayout());
 		mapSize = new JMapSizeCombo();
 		mapSize.addActionListener(new ActionListener() {
 
 			public void actionPerformed(ActionEvent e) {
-				log.trace("Map size: " + mapSize.getValue());
+				LOG.trace("Map size: " + mapSize.getValue());
 			}
 		});
 
@@ -548,6 +558,7 @@ public class SettingsGUI extends JDialog {
 	}
 
 	private void addDirectoriesPanel() {
+		LOG.trace("addDirectoriesPanel");
 		JPanel backGround = createNewTab(I18nUtils.localizedStringForKey("set_directory_title"));
 		backGround.setLayout(new GridBagLayout());
 		JPanel atlasOutputDirPanel = new JPanel(new GridBagLayout());
@@ -578,6 +589,7 @@ public class SettingsGUI extends JDialog {
 	}
 
 	private void addNetworkPanel() {
+		LOG.trace("addNetworkPanel");
 		JPanel backGround = createNewTab(I18nUtils.localizedStringForKey("set_net_title"));
 		backGround.setLayout(new GridBagLayout());
 		GBC gbc_eolh = GBC.eol().fill(GBC.HORIZONTAL);
@@ -666,6 +678,7 @@ public class SettingsGUI extends JDialog {
 	}
 
 	public void createJButtons() {
+		LOG.trace("createJButtons");
 		JPanel buttonPanel = new JPanel(new GridBagLayout());
 		okButton = new JButton(I18nUtils.localizedStringForKey("OK"));
 		cancelButton = new JButton(I18nUtils.localizedStringForKey("Cancel"));
@@ -677,6 +690,7 @@ public class SettingsGUI extends JDialog {
 	}
 
 	private void loadSettings() {
+		LOG.trace("loadSettings()");
 		Settings s = settings;
 
 		unitSystem.setSelectedItem(s.unitSystem);
@@ -769,8 +783,9 @@ public class SettingsGUI extends JDialog {
 		paperAtlas.applySettings(s);
 		display.applySettings(s);
 
-		if (MainGUI.getMainGUI() == null)
+		if (MainGUI.getMainGUI() == null) {
 			return;
+		}
 
 		MainGUI.getMainGUI().updateMapSourcesList();
 
@@ -778,7 +793,7 @@ public class SettingsGUI extends JDialog {
 		try {
 			MainGUI.getMainGUI().checkAndSaveSettings();
 		} catch (Exception e) {
-			log.error("Error saving settings to file", e);
+			LOG.error("Error saving settings to file", e);
 			JOptionPane.showMessageDialog(null,
 					String.format(I18nUtils.localizedStringForKey("set_error_saving_msg"),
 							e.getClass().getSimpleName()),
@@ -789,6 +804,7 @@ public class SettingsGUI extends JDialog {
 	}
 
 	private void addListeners() {
+		LOG.trace("addListeners");
 
 		addWindowListener(new WindowCloseListener());
 
