@@ -43,6 +43,8 @@ import javax.xml.bind.JAXBException;
 import javax.xml.bind.Marshaller;
 import javax.xml.bind.Unmarshaller;
 
+import org.apache.log4j.Logger;
+
 import mobac.gui.mapview.WgsGrid.WgsDensity;
 import mobac.program.model.PaperSize;
 import mobac.program.model.PaperSize.Format;
@@ -55,6 +57,8 @@ import mobac.utilities.I18nUtils;
 public class SettingsGUIPaper extends JPanel {
 	private static final long serialVersionUID = -8265562215604604074L;
 
+	private static final Logger LOG = Logger.getLogger(SettingsGUIPaper.class);
+
 	private static void setModel(SpinnerNumberModel model, double min, double max, Double step) {
 		model.setMaximum(max);
 		model.setMinimum(min);
@@ -84,7 +88,7 @@ public class SettingsGUIPaper extends JPanel {
 	private final JCheckBox jCheckBoxScaleBar = new JCheckBox();
 	private final JCheckBox jCheckBoxWgsGrid = new JCheckBox("", true);
 
-	private final JFileChooser jFileChooser = new JFileChooser();
+	private JFileChooser jFileChooser;
 
 	private final TitledBorder titledBorderActions = SettingsGUI.createSectionBorder("");
 	private final TitledBorder titledBorderAdditions = SettingsGUI.createSectionBorder("");
@@ -139,20 +143,10 @@ public class SettingsGUIPaper extends JPanel {
 
 	public SettingsGUIPaper() {
 		super(new GridBagLayout());
+		LOG.debug("Preparing paper atlas settings panel");
 		jSpinnerCrop.setEditor(new JSpinner.NumberEditor(jSpinnerCrop, "#0'%'"));
 		setUnitSystem(UnitSystem.Metric);
 		i18n();
-		jFileChooser.setFileFilter(new FileFilter() {
-			@Override
-			public boolean accept(File f) {
-				return f.isDirectory() || f.getName().endsWith(".xml");
-			}
-
-			@Override
-			public String getDescription() {
-				return xmlFileFilter;
-			}
-		});
 		jButtonImport.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
 				importFromXml();
@@ -261,7 +255,25 @@ public class SettingsGUIPaper extends JPanel {
 		add(Box.createGlue(), gbc.incY().gridwidth(2).fill());
 	}
 
+	private void prepareFileChooser() {
+		if (jFileChooser == null) {
+			jFileChooser = new JFileChooser();
+			jFileChooser.setFileFilter(new FileFilter() {
+				@Override
+				public boolean accept(File f) {
+					return f.isDirectory() || f.getName().endsWith(".xml");
+				}
+
+				@Override
+				public String getDescription() {
+					return xmlFileFilter;
+				}
+			});
+		}
+	}
+
 	private void importFromXml() {
+		prepareFileChooser();
 		int state = jFileChooser.showOpenDialog(SettingsGUIPaper.this);
 		if (state == JFileChooser.APPROVE_OPTION) {
 			File file = jFileChooser.getSelectedFile();
@@ -279,18 +291,19 @@ public class SettingsGUIPaper extends JPanel {
 	}
 
 	private void exportToXml() {
+		prepareFileChooser();
 		int state = jFileChooser.showSaveDialog(SettingsGUIPaper.this);
 		if (state == JFileChooser.APPROVE_OPTION) {
 			File file = jFileChooser.getSelectedFile();
-			JAXBContext context;
 			try {
-				context = JAXBContext.newInstance(SettingsPaperAtlas.class);
+				JAXBContext context = JAXBContext.newInstance(SettingsPaperAtlas.class);
 				Marshaller m = context.createMarshaller();
 				SettingsPaperAtlas s = new SettingsPaperAtlas();
 				applySettings(s);
 				m.marshal(s, file);
 			} catch (JAXBException ex) {
 				String text = exportError + file.getName() + "\n" + errorReason + ex.getMessage();
+				LOG.error(text);
 				JOptionPane.showMessageDialog(SettingsGUIPaper.this, text, errorTitle, JOptionPane.ERROR_MESSAGE);
 			}
 		}
