@@ -36,6 +36,7 @@ import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
 
+import mobac.exceptions.MapSourceInitializationException;
 import mobac.exceptions.UnrecoverableDownloadException;
 import mobac.mapsources.AbstractHttpMapSourceBase;
 import mobac.mapsources.MapSourceTools;
@@ -45,6 +46,7 @@ import mobac.program.download.TileDownLoader;
 import mobac.program.interfaces.HttpMapSource;
 import mobac.program.interfaces.MapSourceListener;
 import mobac.program.interfaces.MapSpace;
+import mobac.program.interfaces.ReloadableMapSource;
 import mobac.program.jaxb.ColorAdapter;
 import mobac.program.model.MapSourceLoaderInfo;
 import mobac.program.model.TileImageType;
@@ -55,7 +57,7 @@ import mobac.program.tilestore.TileStoreEntry;
  * Custom tile store provider, configurable via settings.xml.
  */
 @XmlRootElement
-public class CustomMapSource extends AbstractHttpMapSourceBase {
+public class CustomMapSource extends AbstractHttpMapSourceBase implements ReloadableMapSource<CustomMapSource> {
 
 	@XmlElement(nillable = false, defaultValue = "Custom")
 	private String name = "Custom";
@@ -112,6 +114,25 @@ public class CustomMapSource extends AbstractHttpMapSourceBase {
 		this.url = url;
 	}
 
+	@Override
+	public void applyChangesFrom(CustomMapSource reloadedMapSource) throws MapSourceInitializationException {
+		if (!name.equals(reloadedMapSource.getName())) {
+			throw new MapSourceInitializationException("The map name has changed");
+		}
+
+		minZoom = reloadedMapSource.minZoom;
+		maxZoom = reloadedMapSource.maxZoom;
+		tileType = reloadedMapSource.tileType;
+		tileUpdate = reloadedMapSource.tileUpdate;
+		url = reloadedMapSource.url;
+		invertYCoordinate = reloadedMapSource.invertYCoordinate;
+		backgroundColor = reloadedMapSource.backgroundColor;
+		ignoreErrors = reloadedMapSource.ignoreErrors;
+		serverParts = reloadedMapSource.serverParts;
+		loaderInfo = reloadedMapSource.loaderInfo;
+		afterUnmarshal(null, null);
+	}
+
 	protected void afterUnmarshal(Unmarshaller u, Object parent) {
 		if (trustedPublicKeys.size() > 0) {
 			sslSocketFactory = MobacSSLHelper.createSSLSocketFactory(trustedPublicKeys);
@@ -161,8 +182,6 @@ public class CustomMapSource extends AbstractHttpMapSourceBase {
 
 	public byte[] getTileData(int zoom, int x, int y, LoadMethod loadMethod)
 			throws IOException, UnrecoverableDownloadException, InterruptedException {
-		if (invertYCoordinate)
-			y = ((1 << zoom) - y - 1);
 
 		if (loadMethod == LoadMethod.CACHE) {
 			TileStoreEntry entry = TileStore.getInstance().getTile(x, y, zoom, this);
@@ -175,6 +194,9 @@ public class CustomMapSource extends AbstractHttpMapSourceBase {
 			return data;
 		}
 		try {
+			if (invertYCoordinate)
+				y = ((1 << zoom) - y - 1);
+
 			return TileDownLoader.getImage(x, y, zoom, this);
 		} catch (Exception e) {
 			if (ignoreErrors) {
@@ -234,8 +256,6 @@ public class CustomMapSource extends AbstractHttpMapSourceBase {
 	}
 
 	public void setLoaderInfo(MapSourceLoaderInfo loaderInfo) {
-		if (this.loaderInfo != null)
-			throw new RuntimeException("LoaderInfo already set");
 		this.loaderInfo = loaderInfo;
 	}
 
