@@ -48,6 +48,10 @@ import java.util.zip.ZipFile;
 
 import javax.swing.JOptionPane;
 
+import org.apache.commons.codec.binary.Hex;
+import org.apache.log4j.Level;
+import org.apache.log4j.Logger;
+
 import mobac.exceptions.MapSourceCreateException;
 import mobac.exceptions.UnrecoverableDownloadException;
 import mobac.exceptions.UpdateFailedException;
@@ -64,10 +68,6 @@ import mobac.utilities.Utilities;
 import mobac.utilities.file.DirOrFileExtFilter;
 import mobac.utilities.file.FileExtFilter;
 
-import org.apache.commons.codec.binary.Hex;
-import org.apache.log4j.Level;
-import org.apache.log4j.Logger;
-
 public class MapPackManager {
 
 	private final Logger log = Logger.getLogger(MapPackManager.class);
@@ -82,8 +82,8 @@ public class MapPackManager {
 		this.mapPackDir = mapPackDir;
 		requiredMapPackVersion = Integer.parseInt(System.getProperty("mobac.mappackversion"));
 		CertificateFactory cf = CertificateFactory.getInstance("X.509");
-		Collection<? extends Certificate> certs = cf.generateCertificates(Utilities
-				.loadResourceAsStream("cert/MapPack.cer"));
+		Collection<? extends Certificate> certs = cf
+				.generateCertificates(Utilities.loadResourceAsStream("cert/MapPack.cer"));
 		mapPackCert = (X509Certificate) certs.iterator().next();
 	}
 
@@ -93,9 +93,13 @@ public class MapPackManager {
 	 * @throws IOException
 	 */
 	public void installUpdates() throws IOException {
+		if (!mapPackDir.isDirectory()) {
+			throw new IOException("Map pack directory does not exist: " + mapPackDir);
+		}
 		File[] newMapPacks = mapPackDir.listFiles(new FileExtFilter(".jar.new"));
-		if (newMapPacks == null)
+		if (newMapPacks == null) {
 			throw new IOException("Failed to enumerate installable mappacks");
+		}
 		for (File newMapPack : newMapPacks) {
 			try {
 				testMapPack(newMapPack);
@@ -108,8 +112,9 @@ public class MapPackManager {
 					File oldMapPack2 = new File(mapPackDir, name + ".old");
 					Utilities.renameFile(oldMapPack, oldMapPack2);
 				}
-				if (!newMapPack.renameTo(oldMapPack))
+				if (!newMapPack.renameTo(oldMapPack)) {
 					throw new IOException("Failed to rename file: " + newMapPack);
+				}
 			} catch (CertificateException e) {
 				Utilities.deleteFile(newMapPack);
 				log.error("Map pack certificate cerificateion failed (" + newMapPack.getName()
@@ -128,8 +133,9 @@ public class MapPackManager {
 			File oldMapPackFile = new File(mapPackFile.getAbsolutePath() + ".old");
 			try {
 				loadMapPack(mapPackFile, mapSourcesManager);
-				if (oldMapPackFile.isFile())
+				if (oldMapPackFile.isFile()) {
 					Utilities.deleteFile(oldMapPackFile);
+				}
 			} catch (MapSourceCreateException e) {
 				if (oldMapPackFile.isFile()) {
 					mapPackFile.deleteOnExit();
@@ -154,8 +160,8 @@ public class MapPackManager {
 		}
 	}
 
-	public void loadMapPack(File mapPackFile, MapSourcesManager mapSourcesManager) throws CertificateException,
-			IOException, MapSourceCreateException {
+	public void loadMapPack(File mapPackFile, MapSourcesManager mapSourcesManager)
+			throws CertificateException, IOException, MapSourceCreateException {
 		// testMapPack(mapPackFile);
 		URLClassLoader urlCl;
 		URL url = mapPackFile.toURI().toURL();
@@ -175,19 +181,19 @@ public class MapPackManager {
 			}
 			mf = null;
 		}
-		MapSourceLoaderInfo loaderInfo = new MapSourceLoaderInfo(LoaderType.MAPPACK, mapPackFile, rev);
 		final Iterator<MapSource> iterator = ServiceLoader.load(MapSource.class, urlCl).iterator();
 
 		while (iterator.hasNext()) {
 			try {
 				MapSource ms = iterator.next();
-				ms.setLoaderInfo(loaderInfo);
+				ms.setLoaderInfo(new MapSourceLoaderInfo(LoaderType.MAPPACK, mapPackFile, rev));
 				mapSourcesManager.addMapSource(ms);
 				log.trace("Loaded map source: " + ms.toString() + " (name: " + ms.getName() + ")");
 			} catch (Error e) {
 				urlCl = null;
-				throw new MapSourceCreateException("Failed to load a map sources from map pack: "
-						+ mapPackFile.getName() + " " + e.getMessage(), e);
+				throw new MapSourceCreateException(
+						"Failed to load a map sources from map pack: " + mapPackFile.getName() + " " + e.getMessage(),
+						e);
 			}
 		}
 	}
@@ -196,28 +202,35 @@ public class MapPackManager {
 		String md5eTag = Settings.getInstance().mapSourcesUpdate.etag;
 		log.debug("Last md5 eTag: " + md5eTag);
 		String updateUrl = System.getProperty("mobac.updateurl");
-		if (updateUrl == null)
+		if (updateUrl == null) {
 			throw new RuntimeException("Update url not present");
+		}
 
 		byte[] data = null;
 
 		// Proxy p = new Proxy(Type.HTTP, InetSocketAddress.createUnresolved("localhost", 8888));
 		HttpURLConnection conn = (HttpURLConnection) new URL(updateUrl).openConnection();
-		conn.setInstanceFollowRedirects(false);
-		if (md5eTag != null)
-			conn.addRequestProperty("If-None-Match", md5eTag);
-		int responseCode = conn.getResponseCode();
-		if (responseCode == HttpURLConnection.HTTP_NOT_MODIFIED) {
-			log.debug("No newer md5 file available");
-			return null;
+		try {
+			conn.setInstanceFollowRedirects(false);
+			if (md5eTag != null) {
+				conn.addRequestProperty("If-None-Match", md5eTag);
+			}
+			int responseCode = conn.getResponseCode();
+			if (responseCode == HttpURLConnection.HTTP_NOT_MODIFIED) {
+				log.debug("No newer md5 file available");
+				return null;
+			}
+			if (responseCode != HttpURLConnection.HTTP_OK) {
+				throw new UpdateFailedException(
+						"Invalid HTTP response: " + responseCode + " for update url " + conn.getURL());
+			}
+			// Case HTTP_OK
+			try (InputStream in = conn.getInputStream()) {
+				data = Utilities.getInputBytes(in);
+			}
+		} finally {
+			conn.disconnect();
 		}
-		if (responseCode != HttpURLConnection.HTTP_OK)
-			throw new UpdateFailedException("Invalid HTTP response: " + responseCode + " for update url "
-					+ conn.getURL());
-		// Case HTTP_OK
-		InputStream in = conn.getInputStream();
-		data = Utilities.getInputBytes(in);
-		in.close();
 		Settings.getInstance().mapSourcesUpdate.etag = conn.getHeaderField("ETag");
 		log.debug("New md5 file retrieved");
 		String md5sumList = new String(data);
@@ -231,17 +244,20 @@ public class MapPackManager {
 	 */
 	public void cleanMapPackDir() throws IOException {
 		File[] newMapPacks = mapPackDir.listFiles(new FileExtFilter(".jar.new"));
-		for (File newMapPack : newMapPacks)
+		for (File newMapPack : newMapPacks) {
 			Utilities.deleteFile(newMapPack);
+		}
 		File[] unverifiedMapPacks = mapPackDir.listFiles(new FileExtFilter(".jar.unverified"));
-		for (File unverifiedMapPack : unverifiedMapPacks)
+		for (File unverifiedMapPack : unverifiedMapPacks) {
 			Utilities.deleteFile(unverifiedMapPack);
+		}
 	}
 
 	/**
 	 * Performs on map sources online update
 	 * 
-	 * @return <ul>
+	 * @return
+	 *         <ul>
 	 *         <li>0: no change in online md5 sum file (based on ETag)</li>
 	 *         <li>-1: Online md5 file is empty indicationg that this MOBAc versiosn is no longer supported</li>
 	 *         <li>x>0: Number of updated map packs</li>
@@ -250,15 +266,18 @@ public class MapPackManager {
 	 */
 	public int updateMapPacks() throws UpdateFailedException, UnrecoverableDownloadException, IOException {
 		String updateBaseUrl = System.getProperty("mobac.updatebaseurl");
-		if (updateBaseUrl == null)
+		if (updateBaseUrl == null) {
 			throw new RuntimeException("Update base url not present");
+		}
 
 		cleanMapPackDir();
 		String md5sumList = downloadMD5SumList();
-		if (md5sumList == null)
+		if (md5sumList == null) {
 			return 0; // no new md5 file available
-		if (md5sumList.length() == 0)
+		}
+		if (md5sumList.length() == 0) {
 			return -1; // empty file means - outdated version
+		}
 		int updateCount = 0;
 		String[] outdatedMapPacks = searchForOutdatedMapPacks(md5sumList);
 		for (String mapPack : outdatedMapPacks) {
@@ -300,33 +319,29 @@ public class MapPackManager {
 	}
 
 	public int getMapPackRevision(File mapPackFile) throws ZipException, IOException {
-		ZipFile zip = new ZipFile(mapPackFile);
-		try {
+		try (ZipFile zip = new ZipFile(mapPackFile)) {
 			ZipEntry entry = zip.getEntry("META-INF/MANIFEST.MF");
-			if (entry == null)
+			if (entry == null) {
 				throw new ZipException("Unable to find MANIFEST.MF");
+			}
 			Manifest mf = new Manifest(zip.getInputStream(entry));
 			Attributes a = mf.getMainAttributes();
 			String mpv = a.getValue("MapPackRevision").trim();
 			return Utilities.parseSVNRevision(mpv);
 		} catch (NumberFormatException e) {
 			return -1;
-		} finally {
-			zip.close();
 		}
 	}
 
 	public File downloadMapPack(String baseURL, String mapPackFilename) throws IOException {
-		if (!mapPackFilename.endsWith(".jar"))
+		if (!mapPackFilename.endsWith(".jar")) {
 			throw new IOException("Invalid map pack filename");
+		}
 		byte[] mapPackData = Utilities.downloadHttpFile(baseURL + mapPackFilename);
 		File newMapPackFile = new File(mapPackDir, mapPackFilename + ".unverified");
-		FileOutputStream out = new FileOutputStream(newMapPackFile);
-		try {
+		try (FileOutputStream out = new FileOutputStream(newMapPackFile)) {
 			out.write(mapPackData);
 			out.flush();
-		} finally {
-			Utilities.closeStream(out);
 		}
 		log.debug("New map pack \"" + mapPackFilename + "\" successfully downloaded");
 		return newMapPackFile;
@@ -344,8 +359,9 @@ public class MapPackManager {
 
 		for (String line : md5s) {
 			line = line.trim();
-			if (line.length() == 0)
+			if (line.length() == 0) {
 				continue;
+			}
 			Matcher m = linePattern.matcher(line);
 			if (!m.matches()) {
 				throw new UpdateFailedException("Invalid content found in md5 list: \"" + line + "\"");
@@ -354,8 +370,9 @@ public class MapPackManager {
 			String filename = m.group(2);
 			// Check if there is already an update map pack
 			File mapPackFile = new File(mapPackDir, filename + ".new");
-			if (!mapPackFile.isFile())
+			if (!mapPackFile.isFile()) {
 				mapPackFile = new File(mapPackDir, filename);
+			}
 			if (!mapPackFile.isFile()) {
 				outdatedMappacks.add(filename);
 				log.debug("local map pack file missing: " + filename);
@@ -363,18 +380,17 @@ public class MapPackManager {
 			}
 			try {
 				String localmd5 = generateMappackMD5(mapPackFile);
-				if (localmd5.equals(md5))
+				if (localmd5.equals(md5)) {
 					continue; // No change in map pack
-				log.debug("Found outdated map pack: \"" + filename + "\" local md5: " + localmd5 + " remote md5: "
-						+ md5);
+				}
+				log.debug(
+						"Found outdated map pack: \"" + filename + "\" local md5: " + localmd5 + " remote md5: " + md5);
 				outdatedMappacks.add(filename);
 			} catch (Exception e) {
 				log.error("Failed to generate md5sum of " + mapPackFile, e);
 			}
 		}
-		String[] result = new String[outdatedMappacks.size()];
-		outdatedMappacks.toArray(result);
-		return result;
+		return outdatedMappacks.toArray(new String[outdatedMappacks.size()]);
 	}
 
 	/**
@@ -387,24 +403,26 @@ public class MapPackManager {
 	 * @throws NoSuchAlgorithmException
 	 */
 	public String generateMappackMD5(File mapPackFile) throws IOException, NoSuchAlgorithmException {
-		ZipFile zip = new ZipFile(mapPackFile);
-		try {
+		try (ZipFile zip = new ZipFile(mapPackFile)) {
 			Enumeration<? extends ZipEntry> entries = zip.entries();
 			MessageDigest md5Total = MessageDigest.getInstance("MD5");
 			MessageDigest md5 = MessageDigest.getInstance("MD5");
 			while (entries.hasMoreElements()) {
 				ZipEntry entry = entries.nextElement();
 
-				if (entry.isDirectory())
+				if (entry.isDirectory()) {
 					continue;
+				}
 				// Do not hash files from META-INF
 				String name = entry.getName();
-				if (name.toUpperCase().startsWith("META-INF"))
+				if (name.toUpperCase().startsWith("META-INF")) {
 					continue;
+				}
 				md5.reset();
-				InputStream in = zip.getInputStream(entry);
-				byte[] data = Utilities.getInputBytes(in);
-				in.close();
+				byte[] data;
+				try (InputStream in = zip.getInputStream(entry)) {
+					data = Utilities.getInputBytes(in);
+				}
 				// name = name.replaceAll("\\\\", "/");
 				byte[] digest = md5.digest(data);
 				log.trace("Hashsum " + Hex.encodeHexString(digest) + " includes \"" + name + "\"");
@@ -414,8 +432,6 @@ public class MapPackManager {
 			String md5sum = Hex.encodeHexString(md5Total.digest());
 			log.trace("md5sum of " + mapPackFile.getName() + ": " + md5sum);
 			return md5sum;
-		} finally {
-			zip.close();
 		}
 	}
 
@@ -428,41 +444,45 @@ public class MapPackManager {
 	 */
 	public void testMapPack(File mapPackFile) throws IOException, CertificateException {
 		String fileName = mapPackFile.getName();
-		JarFile jf = new JarFile(mapPackFile, true);
-		try {
+		try (JarFile jf = new JarFile(mapPackFile, true)) {
 			Enumeration<JarEntry> it = jf.entries();
 			while (it.hasMoreElements()) {
 				JarEntry entry = it.nextElement();
 				// We verify only class files
-				if (!entry.getName().endsWith(".class"))
+				if (!entry.getName().endsWith(".class")) {
 					continue; // directory or other entry
+				}
 				// Get the input stream (triggers) the signature verification for the specific class
 				Utilities.readFully(jf.getInputStream(entry));
-				if (entry.getCodeSigners() == null)
+				if (entry.getCodeSigners() == null) {
 					throw new CertificateException("Unsigned class file found: " + entry.getName());
+				}
 				CodeSigner signer = entry.getCodeSigners()[0];
 				List<? extends Certificate> cp = signer.getSignerCertPath().getCertificates();
-				if (cp.size() > 1)
+				if (cp.size() > 1) {
 					throw new CertificateException("Signature certificate not accepted: "
 							+ "certificate path contains more than one certificate");
+				}
 				// Compare the used certificate with the mapPack certificate
-				if (!mapPackCert.equals(cp.get(0)))
-					throw new CertificateException("Signature certificate not accepted: "
-							+ "not the MapPack signer certificate");
+				if (!mapPackCert.equals(cp.get(0))) {
+					throw new CertificateException(
+							"Signature certificate not accepted: " + "not the MapPack signer certificate");
+				}
 			}
 			Manifest mf = jf.getManifest();
 			Attributes a = mf.getMainAttributes();
 			String mpv = a.getValue("MapPackVersion");
-			if (mpv == null)
+			if (mpv == null) {
 				throw new IOException("MapPackVersion info missing!");
+			}
 			int mapPackVersion = Integer.parseInt(mpv);
-			if (requiredMapPackVersion != mapPackVersion)
+			if (requiredMapPackVersion != mapPackVersion) {
 				throw new IOException("This pack \"" + fileName + "\" is not compatible with this MOBAC version.");
+			}
 			ZipEntry entry = jf.getEntry("META-INF/services/mobac.program.interfaces.MapSource");
-			if (entry == null)
+			if (entry == null) {
 				throw new IOException("MapSources services list is missing in file " + fileName);
-		} finally {
-			jf.close();
+			}
 		}
 
 	}
