@@ -26,11 +26,6 @@ import java.util.Properties;
 import java.util.TreeMap;
 import java.util.logging.Handler;
 
-import mobac.StartMOBAC;
-import mobac.utilities.GUIExceptionHandler;
-import mobac.utilities.Juli2Log4jHandler;
-import mobac.utilities.OSUtilities;
-
 import org.apache.log4j.ConsoleAppender;
 import org.apache.log4j.FileAppender;
 import org.apache.log4j.Layout;
@@ -40,6 +35,11 @@ import org.apache.log4j.PatternLayout;
 import org.apache.log4j.SimpleLayout;
 import org.apache.log4j.xml.DOMConfigurator;
 
+import mobac.StartMOBAC;
+import mobac.utilities.GUIExceptionHandler;
+import mobac.utilities.Juli2Log4jHandler;
+import mobac.utilities.OSUtilities;
+
 public class Logging {
 
 	protected static final String CONFIG_FILENAME = "log4j.xml";
@@ -158,6 +158,7 @@ public class Logging {
 					+ ")");
 			log.info("Java VM: " + GUIExceptionHandler.prop("java.vm.name") + " ("
 					+ GUIExceptionHandler.prop("java.runtime.version") + ")");
+			log.info("Available processors: " + Runtime.getRuntime().availableProcessors());
 			log.info("Directories:" /**/
 					+ n + "currentDir: \t\t" + DirectoryManager.currentDir /**/
 					+ n + "programDir: \t\t" + DirectoryManager.programDir /**/
@@ -187,9 +188,9 @@ public class Logging {
 		}
 		if (log.isTraceEnabled()) {
 			Properties props = System.getProperties();
-			StringWriter sw = new StringWriter(2 << 13);
+			StringWriter sw = new StringWriter(8192);
 			sw.write("System properties:\n");
-			TreeMap<Object, Object> sortedProps = new TreeMap<Object, Object>(props);
+			TreeMap<Object, Object> sortedProps = new TreeMap<>(props);
 			for (Entry<Object, Object> entry : sortedProps.entrySet()) {
 				sw.write(entry.getKey() + " = " + entry.getValue() + "\n");
 			}
