@@ -81,7 +81,8 @@ public class MagellanRmp extends AtlasCreator {
 				// if (max.x - min.x > 18000 || max.y - min.y > 18000)
 				// throw new AtlasTestException("Map too large. Max size 18000x18000");
 				if (map.getParameters() != null) {
-					if (!(map.getParameters().getFormat().getDataWriterBuilder() instanceof TileImageJpegDataWriterBuilder))
+					if (!(map.getParameters().getFormat()
+							.getDataWriterBuilder() instanceof TileImageJpegDataWriterBuilder))
 						throw new AtlasTestException("Only JPEG formats are supported", map);
 				}
 			}
@@ -108,8 +109,8 @@ public class MagellanRmp extends AtlasCreator {
 		ImageIO.setUseCache(false);
 
 		MultiImage layerImage = new MultiImage(mapSource, mapDlTileProvider, map);
-		try {
-			RmpLayer layer = createLayer(layerImage, layerNum);
+		try (TileImageDataWriter tileWriter = tileWriterBuilder.build()) {
+			RmpLayer layer = createLayer(layerImage, layerNum, tileWriter);
 			String layerName = RmpTools.buildTileName(imageName, layerNum);
 			TLMEntry tlmEntry = layer.getTLMFile(layerName);
 			rmpWriter.prepareFileEntry(tlmEntry);
@@ -151,16 +152,15 @@ public class MagellanRmp extends AtlasCreator {
 	 *            image to get data from
 	 * @param layer
 	 *            Layer number - for status output only
+	 * @param tileWriter
 	 * @return TLM instance
 	 * @throws InterruptedException
 	 * @throws MapCreationException
 	 * @throws IOException
 	 */
-	public RmpLayer createLayer(MultiImage si, int layer)
+	public RmpLayer createLayer(MultiImage si, int layer, TileImageDataWriter tileWriter)
 			throws InterruptedException, MapCreationException, IOException {
 
-		int count = 0;
-
 		/* --- Create instance --- */
 		RmpLayer rmpLayer = new RmpLayer(this);
 
@@ -191,24 +191,21 @@ public class MagellanRmp extends AtlasCreator {
 		double x_end = (rect.getEast() + 180.0) / tile_width;
 		double y_end = (rect.getSouth() + 90.0) / tile_height;
 
-		try (TileImageDataWriter tileWriter = tileWriterBuilder.build()) {
-			/*
-			 * Create the tiles - process works column wise, starting on the top left corner of the destination area.
-			 */
-			for (int x = x_start; x < x_end; x++) {
-				for (int y = y_start; y < y_end; y++) {
-					count++;
+		/*
+		 * Create the tiles - process works column wise, starting on the top left corner of the destination area.
+		 */
+		for (int x = x_start; x < x_end; x++) {
+			for (int y = y_start; y < y_end; y++) {
 
-					/* --- Create tile --- */
-					BoundingRect subrect = new BoundingRect(y * tile_height - 90, (y + 1) * tile_height - 90,
-							x * tile_width - 180, (x + 1) * tile_width - 180);
-					Tiledata td = new Tiledata(tileWriter);
-					td.posx = x;
-					td.posy = y;
-					td.rect = subrect;
-					td.si = si;
-					rmpLayer.addPreparedImage(td);
-				}
+				/* --- Create tile --- */
+				BoundingRect subrect = new BoundingRect(y * tile_height - 90, (y + 1) * tile_height - 90,
+						x * tile_width - 180, (x + 1) * tile_width - 180);
+				Tiledata td = new Tiledata(tileWriter);
+				td.posx = x;
+				td.posy = y;
+				td.rect = subrect;
+				td.si = si;
+				rmpLayer.addPreparedImage(td);
 			}
 		}
 		/* --- Build the TLM file --- */
