@@ -32,6 +32,17 @@ import java.util.List;
 import java.util.Map;
 import java.util.TreeMap;
 
+import com.sleepycat.je.DatabaseException;
+import com.sleepycat.je.Environment;
+import com.sleepycat.je.EnvironmentConfig;
+import com.sleepycat.je.EnvironmentLockedException;
+import com.sleepycat.persist.EntityCursor;
+import com.sleepycat.persist.EntityStore;
+import com.sleepycat.persist.PrimaryIndex;
+import com.sleepycat.persist.StoreConfig;
+import com.sleepycat.persist.evolve.Mutations;
+import com.sleepycat.persist.evolve.Renamer;
+
 import mobac.exceptions.TileStoreException;
 import mobac.program.interfaces.MapSource;
 import mobac.program.model.Settings;
@@ -45,17 +56,6 @@ import mobac.utilities.file.DeleteFileFilter;
 import mobac.utilities.file.DirInfoFileFilter;
 import mobac.utilities.file.DirectoryFileFilter;
 
-import com.sleepycat.je.DatabaseException;
-import com.sleepycat.je.Environment;
-import com.sleepycat.je.EnvironmentConfig;
-import com.sleepycat.je.EnvironmentLockedException;
-import com.sleepycat.persist.EntityCursor;
-import com.sleepycat.persist.EntityStore;
-import com.sleepycat.persist.PrimaryIndex;
-import com.sleepycat.persist.StoreConfig;
-import com.sleepycat.persist.evolve.Mutations;
-import com.sleepycat.persist.evolve.Renamer;
-
 /**
  * The new database based tile store implementation.
  */
@@ -77,7 +77,7 @@ public class BerkeleyDbTileStore extends TileStore {
 	public BerkeleyDbTileStore() throws TileStoreException {
 		super();
 		acquireTileStoreLock();
-		tileDbMap = new TreeMap<String, TileDatabase>();
+		tileDbMap = new TreeMap<>();
 
 		envConfig = new EnvironmentConfig();
 		envConfig.setTransactional(false);
@@ -124,9 +124,10 @@ public class BerkeleyDbTileStore extends TileStore {
 			// Try acquiring the lock without blocking. This method returns
 			// null or throws an exception if the file is already locked.
 			tileStoreLock = channel.tryLock();
-			if (tileStoreLock == null)
+			if (tileStoreLock == null) {
 				throw new TileStoreException(
-						"Unable to obtain tile store lock - " + "another instance of Mobile Atlas Creator is running!");
+						"Unable to obtain tile store lock - another instance of Mobile Atlas Creator is running!");
+			}
 
 			// // Release the lock
 			// lock.release();
