@@ -35,13 +35,15 @@ public class I18nUtils {
 	private static ResourceBundle STRING_RESOURCE = null;
 
 	public static String localizedStringForKey(String key, Object... args) {
-		if (STRING_RESOURCE == null)
+		if (STRING_RESOURCE == null) {
 			I18nUtils.updateLocalizedStringFormSettings();
+		}
 		String str = null;
 		try {
 			str = STRING_RESOURCE.getString(key);
-			if (args.length > 0)
+			if (args.length > 0) {
 				str = String.format(str, args);
+			}
 		} catch (Exception e) {
 			str = key;
 		}
