@@ -691,15 +691,10 @@ public class Utilities {
 	}
 
 	public static void copyFile(File source, File target) throws IOException {
-		FileChannel in = null;
-		FileChannel out = null;
-		try {
-			in = (new FileInputStream(source)).getChannel();
-			out = (new FileOutputStream(target)).getChannel();
-			in.transferTo(0, source.length(), out);
-		} finally {
-			close(in);
-			close(out);
+		try (FileInputStream in = new FileInputStream(source)) {
+			try (FileOutputStream out = new FileOutputStream(target)) {
+				in.getChannel().transferTo(0, source.length(), out.getChannel());
+			}
 		}
 	}
 
